@@ -116,15 +116,15 @@ func init() {
 		"time":                  "Returns the execution run time of a command or block",
 		"tmp":                   "Create a temporary file and write to it",
 		"tout":                  "Print a string to the STDOUT and set it's data-type",
-		"tread":                 "`read` a line of input from the user and store as a user defined *typed* variable",
+		"tread":                 "`read` a line of input from the user and store as a user defined *typed* variable (deprecated)",
 		"true":                  "Returns a `true` value",
 		"try":                   "Handles errors inside a block of code",
 		"trypipe":               "Checks state of each function in a pipeline and exits block on error",
 		"version":               "Get Murex version",
 		"while":                 "Loop until condition false",
 
-		"base64": "Encode or decode a base64 string",
 		"!bz2":   "Decompress a bz2 file",
+		"base64": "Encode or decode a base64 string",
 		"gz":     "Compress or decompress a gzip file",
 		"qr":     "Creates a QR code from STDIN",
 		"select": "Inlining SQL into shell pipelines",
@@ -301,9 +301,9 @@ func init() {
 		"while":                 "while",
 		"!while":                "while",
 
+		"!bz2":    "!bz2",
 		"base64":  "base64",
 		"!base64": "base64",
-		"!bz2":    "!bz2",
 		"gz":      "gz",
 		"!gz":     "gz",
 		"qr":      "qr",
