@@ -2,11 +2,9 @@ package hcl
 
 import (
 	"context"
-	"strconv"
 
 	"github.com/hashicorp/hcl"
 	"github.com/lmorg/murex/config"
-	"github.com/lmorg/murex/debug"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/stdio"
 	"github.com/lmorg/murex/lang/types"
@@ -56,46 +54,13 @@ func readArrayWithType(ctx context.Context, read stdio.Io, callback func(interfa
 	return lang.ArrayWithTypeTemplate(ctx, types.Json, marshaller, hcl.Unmarshal, read, callback)
 }
 
-func readMap(read stdio.Io, _ *config.Config, callback func(key, value string, last bool)) error {
-	b, err := read.ReadAll()
-	if err != nil {
-		return err
+func readMap(read stdio.Io, _ *config.Config, callback func(*stdio.Map)) error {
+	// Create a marshaller function to pass to ArrayWithTypeTemplate
+	marshaller := func(v interface{}) ([]byte, error) {
+		return json.Marshal(v, read.IsTTY())
 	}
 
-	var jObj interface{}
-	err = hcl.Unmarshal(b, &jObj)
-	if err == nil {
-
-		switch v := jObj.(type) {
-		case []interface{}:
-			for i := range jObj.([]interface{}) {
-				j, err := json.Marshal(jObj.([]interface{})[i], false)
-				if err != nil {
-					return err
-				}
-				callback(strconv.Itoa(i), string(j), i != len(jObj.([]interface{}))-1)
-			}
-
-		case map[string]interface{}, map[interface{}]interface{}:
-			i := 1
-			for key := range jObj.(map[string]interface{}) {
-				j, err := json.Marshal(jObj.(map[string]interface{})[key], false)
-				if err != nil {
-					return err
-				}
-				callback(key, string(j), i != len(jObj.(map[string]interface{})))
-				i++
-			}
-			return nil
-
-		default:
-			if debug.Enabled {
-				panic(v)
-			}
-		}
-		return nil
-	}
-	return err
+	return lang.MapTemplate(types.Json, marshaller, hcl.Unmarshal, read, callback)
 }
 
 func readIndex(p *lang.Process, params []string) error {
