@@ -3,10 +3,12 @@ package expressions
 import (
 	"encoding/json"
 	"fmt"
+	"strings"
 
 	"github.com/lmorg/murex/lang/expressions/primitives"
 	"github.com/lmorg/murex/lang/expressions/symbols"
 	"github.com/lmorg/murex/lang/types"
+	"github.com/lmorg/murex/utils/alter"
 )
 
 func scalarNameDetokenised(r []rune) []rune {
@@ -306,3 +308,59 @@ func expAssignDivide(tree *ParserT) error {
 		},
 	})
 }
+
+func expAssignMerge(tree *ParserT) error {
+	left, right, err := tree.getLeftAndRightSymbols()
+	if err != nil {
+		return err
+	}
+
+	if left.key != symbols.Bareword {
+		return raiseError(tree.expression, left, 0, fmt.Sprintf(
+			"left side of %s should be a bareword, instead got %s",
+			tree.currentSymbol().key, left.key))
+	}
+
+	v, dt, err := tree.getVar(left.value, varAsValue)
+	if err != nil {
+		if !tree.StrictTypes() && strings.Contains(err.Error(), "does not exist") {
+			// var doesn't exist and we have strict types disabled so lets create var
+			err = tree.setVar(left.value, right.dt.Value, right.dt.DataType())
+			if err != nil {
+				return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
+			}
+			return tree.foldAst(&astNodeT{
+				key: symbols.Calculated,
+				pos: tree.ast[tree.astPos].pos,
+				dt: &primitives.DataType{
+					Primitive: primitives.Null,
+					Value:     nil,
+				},
+			})
+		} else {
+			return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
+		}
+	}
+
+	merged, err := alter.Merge(tree.p.Context, v, nil, right.dt.Value)
+	if err != nil {
+		return raiseError(tree.expression, left, 0, fmt.Sprintf(
+			"cannot perform merge '%s' into '%s': %s",
+			right.Value(), left.Value(),
+			err.Error()))
+	}
+
+	err = tree.setVar(left.value, merged, dt)
+	if err != nil {
+		return raiseError(tree.expression, tree.currentSymbol(), 0, err.Error())
+	}
+
+	return tree.foldAst(&astNodeT{
+		key: symbols.Calculated,
+		pos: tree.ast[tree.astPos].pos,
+		dt: &primitives.DataType{
+			Primitive: primitives.Null,
+			Value:     nil,
+		},
+	})
+}
