@@ -1,14 +1,23 @@
 package lang
 
 import (
+	"context"
+	"strings"
+
 	"github.com/lmorg/murex/builtins/pipes/streams"
-	"github.com/lmorg/murex/lang/parameters"
+	"github.com/lmorg/murex/lang/expressions/functions"
 	"github.com/lmorg/murex/lang/ref"
 	"github.com/lmorg/murex/lang/runmode"
 	"github.com/lmorg/murex/lang/state"
 )
 
-func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
+var ParseBlock func(block []rune) (*[]functions.FunctionT, error)
+var ParseExpression func([]rune, int, bool) (int, error)
+var ParseStatementParameters func([]rune, *Process) (string, []string, error)
+
+const ExpressionFunctionName = "expr"
+
+func compile(tree *[]functions.FunctionT, parent *Process) (*[]Process, int) {
 	if parent == nil {
 		panic("nil parent")
 	}
@@ -18,14 +27,14 @@ func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
 	}
 
 	rm := parent.RunMode
-	if len(*tree) > 0 && (*tree)[0].Name == "runmode" {
-		params := parameters.Parameters{Tokens: (*tree)[0].ParamTokens}
-		err := ParseParameters(parent, &params)
+	if len(*tree) > 0 && (string((*tree)[0].Command) == "runmode" ||
+		string((*tree)[0].Command) == "runmode:") {
+		_, params, err := ParseStatementParameters((*tree)[0].Raw, parent)
 		if err != nil {
 			return nil, ErrUnableToParseParametersInRunmode
 		}
 
-		switch params.StringAll() {
+		switch strings.Join(params, " ") {
 		case "try function":
 			rm = runmode.FunctionTry
 			parent.Scope.RunMode = rm
@@ -51,42 +60,33 @@ func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
 		*tree = (*tree)[1:]
 	}
 
-	procs = make([]Process, len(*tree))
+	procs := make([]Process, len(*tree))
 
 	for i := range *tree {
 		procs[i].State.Set(state.MemAllocated)
-		procs[i].Name.Set((*tree)[i].Name)
-		procs[i].IsMethod = (*tree)[i].Method
-		procs[i].OperatorLogicAnd = (*tree)[i].LogicAnd
-		procs[i].OperatorLogicOr = (*tree)[i].LogicOr
+		procs[i].raw = (*tree)[i].Raw
+		procs[i].Name.SetRune((*tree)[i].Command)
+		procs[i].Parameters.PreParsed = (*tree)[i].Parameters
+		procs[i].namedPipes = (*tree)[i].NamedPipes
+		procs[i].IsMethod = (*tree)[i].Properties.Method()
+		procs[i].OperatorLogicAnd = (*tree)[i].Properties.LogicAnd()
+		procs[i].OperatorLogicOr = (*tree)[i].Properties.LogicOr()
 		procs[i].Background.Set(parent.Background.Get())
 		procs[i].Parent = parent
 		procs[i].Scope = parent.Scope
 		procs[i].WaitForTermination = make(chan bool)
-		procs[i].RunMode = rm //parent.RunMode //rm
+		procs[i].RunMode = rm //parent.RunMode
 		procs[i].Config = parent.Config
 		procs[i].Tests = parent.Tests
 		procs[i].Variables = parent.Variables
-		procs[i].Parameters.SetTokens((*tree)[i].ParamTokens)
-		procs[i].Done = func() {}
-		procs[i].Kill = func() {}
 		procs[i].PromptId = parent.PromptId
 		procs[i].CCEvent = parent.CCEvent
 		procs[i].CCExists = parent.CCExists
-
 		procs[i].FileRef = &ref.File{Source: parent.FileRef.Source}
+		procs[i].Forks = NewForkManagement()
 
-		if (*tree)[i].LineNumber == 0 {
-			procs[i].FileRef.Column = (*tree)[i].ColNumber + parent.FileRef.Column
-		} else {
-			procs[i].FileRef.Column = (*tree)[i].ColNumber
-		}
-
-		if parent.Id == 0 {
-			procs[i].FileRef.Line = (*tree)[i].LineNumber + parent.FileRef.Line + 1
-		} else {
-			procs[i].FileRef.Line = (*tree)[i].LineNumber + parent.FileRef.Line
-		}
+		procs[i].FileRef.Column = parent.FileRef.Column + (*tree)[i].ColumnN
+		procs[i].FileRef.Line = (*tree)[i].LineN
 
 		// Define previous and next processes:
 		switch {
@@ -121,7 +121,7 @@ func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
 			// first
 			procs[0].Stdin = parent.Stdin
 
-		case (*tree)[i].NewChain:
+		case (*tree)[i].Properties.NewChain():
 			// new chain
 			procs[i].Stdin = streams.NewStdin()
 			//procs[i].Stdin = new(null.Null)
@@ -129,19 +129,17 @@ func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
 
 		// Define stdout / stderr interfaces:
 		switch {
-		case (*tree)[i].PipeOut:
+		case (*tree)[i].Properties.PipeOut():
 			if i+1 == len(procs) {
-				errNo = ErrPipingToNothing
-				return
+				return nil, ErrPipingToNothing
 			}
 			procs[i+1].Stdin = streams.NewStdin()
 			procs[i].Stdout = procs[i].Next.Stdin
 			procs[i].Stderr = procs[i].Parent.Stderr
 
-		case (*tree)[i].PipeErr:
+		case (*tree)[i].Properties.PipeErr():
 			if i+1 == len(procs) {
-				errNo = ErrPipingToNothing
-				return
+				return nil, ErrPipingToNothing
 			}
 			procs[i+1].Stdin = streams.NewStdin()
 			procs[i].Stdout = procs[i].Parent.Stderr //Stdout
@@ -152,11 +150,22 @@ func compile(tree *AstNodes, parent *Process) (procs []Process, errNo int) {
 			procs[i].Stderr = procs[i].Parent.Stderr
 		}
 
+		procs[i].Context, procs[i].Done = context.WithCancel(context.Background())
+		procs[i].Kill = func() {
+			procs[i].Stdin.ForceClose()
+			procs[i].Stdout.ForceClose()
+			procs[i].Stderr.ForceClose()
+			procs[i].Done()
+		}
+
+		if len((*tree)[i].Cast) != 0 {
+			procs[i].Stdin.SetDataType(string((*tree)[i].Cast))
+		}
 	}
 
 	for i := range *tree {
-		createProcess(&procs[i], !(*tree)[i].NewChain)
+		createProcess(&procs[i], !(*tree)[i].Properties.NewChain())
 	}
 
-	return
+	return &procs, 0
 }
