@@ -10,12 +10,6 @@ import (
 	"github.com/lmorg/murex/utils/consts"
 )
 
-// SplitPath takes a $PATH (or similar) string and splits it into an array of paths
-func SplitPath(envPath string) []string {
-	split := strings.Split(envPath, ":")
-	return split
-}
-
 func listExes(path string, exes map[string]bool) {
 	files, _ := ioutil.ReadDir(path)
 	for _, f := range files {
