@@ -1,6 +1,7 @@
 package test
 
 import (
+	"fmt"
 	"regexp"
 	"strings"
 	"testing"
@@ -26,7 +27,7 @@ func RunMurexTests(tests []MurexTest, t *testing.T) {
 	t.Helper()
 	count.Tests(t, len(tests))
 
-	defaults.Defaults(config.InitConf, false)
+	defaults.Config(config.InitConf, false)
 	lang.InitEnv()
 
 	for i := range tests {
@@ -34,7 +35,7 @@ func RunMurexTests(tests []MurexTest, t *testing.T) {
 
 		fork := lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_NEW_MODULE | lang.F_NO_STDIN | lang.F_CREATE_STDOUT | lang.F_CREATE_STDERR)
 		fork.Name.Set("RunMurexTests()")
-		fork.FileRef = &ref.File{Source: &ref.Source{Module: "murex/" + t.Name()}}
+		fork.FileRef = &ref.File{Source: &ref.Source{Module: fmt.Sprintf("murex/%s-%d", t.Name(), i)}}
 		exitNum, err := fork.Execute([]rune(tests[i].Block))
 		if err != nil {
 			t.Errorf("Cannot execute script on test %d", i)
@@ -93,7 +94,7 @@ func RunMurexTestsRx(tests []MurexTest, t *testing.T) {
 	t.Helper()
 	count.Tests(t, len(tests))
 
-	defaults.Defaults(config.InitConf, false)
+	defaults.Config(config.InitConf, false)
 	lang.InitEnv()
 
 	for i := range tests {
@@ -101,7 +102,7 @@ func RunMurexTestsRx(tests []MurexTest, t *testing.T) {
 
 		fork := lang.ShellProcess.Fork(lang.F_FUNCTION | lang.F_NEW_MODULE | lang.F_NO_STDIN | lang.F_CREATE_STDOUT | lang.F_CREATE_STDERR)
 		fork.Name.Set("RunMurexTestsRx()")
-		fork.FileRef = &ref.File{Source: &ref.Source{Module: "murex/" + t.Name()}}
+		fork.FileRef = &ref.File{Source: &ref.Source{Module: fmt.Sprintf("murex/%s-%d", t.Name(), i)}}
 		exitNum, err := fork.Execute([]rune(tests[i].Block))
 		if err != nil {
 			t.Errorf("Cannot execute script on test %d", i)
