@@ -17,16 +17,15 @@ func TestCropCaption(t *testing.T) {
 
 	defer func() {
 		if r := recover(); r != nil {
-			t.Errorf("Panic raised on iteration %d,%d,%d: %s", caption, maxLen, cellWidth, r)
+			t.Errorf("panic raised on iteration %d,%d,%d: %s", caption, maxLen, cellWidth, r)
 		}
 	}()
 
 	for caption = 0; caption < 101; caption++ {
 		for maxLen = 0; maxLen < 101; maxLen++ {
 			for cellWidth = 0; cellWidth < 101; cellWidth++ {
-				cropCaption(strings.Repeat("s", caption), maxLen, cellWidth)
+				_ = cropCaption(strings.Repeat("s", caption), maxLen, cellWidth)
 			}
 		}
 	}
-
 }
